==> zio-aws-kafka_2.13-5.17.104.3-sources.jar: zio/aws/kafka/model/UpdateClusterKafkaVersionResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateClusterKafkaVersionResponse(
    clusterArn: Option[__string] = None,
    clusterOperationArn: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse = {
    import UpdateClusterKafkaVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
      .builder()
      .optionallyWith(
        clusterArn.map(value => __string.unwrap(value): java.lang.String)
      )(_.clusterArn)
      .optionallyWith(
        clusterOperationArn.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.clusterOperationArn)
      .build()
  }
  def asReadOnly
      : zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly =
    zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.wrap(buildAwsValue())
}
object UpdateClusterKafkaVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.UpdateClusterKafkaVersionResponse =
      zio.aws.kafka.model.UpdateClusterKafkaVersionResponse(
        clusterArn.map(value => value),
        clusterOperationArn.map(value => value)
      )
    def clusterArn: Option[__string]
    def clusterOperationArn: Option[__string]
    def getClusterArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clusterArn", clusterArn)
    def getClusterOperationArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clusterOperationArn", clusterOperationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ) extends zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly {
    override val clusterArn: Option[__string] = scala
      .Option(impl.clusterArn())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
    override val clusterOperationArn: Option[__string] = scala
      .Option(impl.clusterOperationArn())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ): zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.151.2-sources.jar: zio/aws/kafka/model/UpdateClusterKafkaVersionResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateClusterKafkaVersionResponse(
    clusterArn: Option[__string] = None,
    clusterOperationArn: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse = {
    import UpdateClusterKafkaVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
      .builder()
      .optionallyWith(clusterArn.map(value => value: java.lang.String))(
        _.clusterArn
      )
      .optionallyWith(
        clusterOperationArn.map(value => value: java.lang.String)
      )(_.clusterOperationArn)
      .build()
  }
  def asReadOnly
      : zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly =
    zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.wrap(buildAwsValue())
}
object UpdateClusterKafkaVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.UpdateClusterKafkaVersionResponse =
      zio.aws.kafka.model.UpdateClusterKafkaVersionResponse(
        clusterArn.map(value => value),
        clusterOperationArn.map(value => value)
      )
    def clusterArn: Option[__string]
    def clusterOperationArn: Option[__string]
    def getClusterArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clusterArn", clusterArn)
    def getClusterOperationArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clusterOperationArn", clusterOperationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ) extends zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly {
    override val clusterArn: Option[__string] =
      scala.Option(impl.clusterArn()).map(value => value: __string)
    override val clusterOperationArn: Option[__string] =
      scala.Option(impl.clusterOperationArn()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.UpdateClusterKafkaVersionResponse
  ): zio.aws.kafka.model.UpdateClusterKafkaVersionResponse.ReadOnly =
    new Wrapper(impl)
}
